translate.convert.oo2po

Package translate :: Package convert :: Module oo2po |
[hide private]
[frames] | no frames]

# Module oo2po

source code

convert an OpenOffice.org (SDF) localization file to Gettext PO localization files

See: http://translate.sourceforge.net/wiki/toolkit/oo2po for examples and usage instructions

Classes | [hide private]
| oo2po

Functions | [hide private]
verifyoptions(options) verifies the commandline options | source code
convertoo(inputfile, outputfile, templates, pot=False, sourcelanguage=None, targetlanguage=None, duplicatestyle="msgid_comment", multifilestyle="single") reads in stdin using inputstore class, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Imports: os, sys, po, oo